import threading
from edgeiq import bounding_box as bounding_box, constants as constants
from enum import Enum
from typing import Any

class CameraFailedToStart(RuntimeError):
    def __init__(self, cmd, backend, append: str = ...) -> None: ...

class CameraConnectionLost(RuntimeError):
    def __init__(self) -> None: ...

class _BaseVideoStream:
    def __init__(self, cmd, backend) -> None: ...
    def start(self): ...
    @property
    def fps(self): ...
    def read(self): ...
    def read_non_blocking(self): ...
    def stop(self) -> None: ...
    def __enter__(self): ...
    def __exit__(self, type, value, traceback) -> None: ...

class WebcamVideoStream(_BaseVideoStream):
    def __init__(self, cam: int = ...) -> None: ...

class GStreamerVideoStream(_BaseVideoStream):
    def __init__(self, cam: int = ..., display_width: int = ..., display_height: int = ..., framerate: int = ...) -> None: ...

class GStreamerCustomVideoStream(_BaseVideoStream):
    def __init__(self, cmd) -> None: ...

class FrameRotation(Enum):
    ROTATE_NONE: int
    ROTATE_90: int
    ROTATE_180: int

class JetsonCameraMode(Enum):
    IMX219_3264x2468_21_0: int
    IMX219_3264x1848_28_1: int
    IMX219_1920x1080_30_2: int
    IMX219_1640x1232_30_3: int
    IMX477_4032x3040_30_0: int
    IMX477_1920x1080_60_1: int
    IMX477_2560x1440_40_3: int

class JetsonVideoStream(_BaseVideoStream):
    def __init__(self, cam: int = ..., rotation=..., camera_mode=..., display_width: int = ..., display_height: int = ...) -> None: ...

class IPVideoStream(_BaseVideoStream):
    def __init__(self, url) -> None: ...

class FPS:
    def __init__(self) -> None: ...
    def start(self): ...
    def stop(self): ...
    def update(self) -> None: ...
    def get_elapsed_seconds(self): ...
    def compute_fps(self): ...

class NoMoreFrames(RuntimeError):
    def __init__(self) -> None: ...

class _FileVideoStreamThread(threading.Thread):
    def __init__(self, stream, queue_size, *args, **kwargs) -> None: ...
    @property
    def more(self): ...
    def read(self): ...
    def stop(self) -> None: ...
    def run(self) -> None: ...

class _RealtimeFileVideoStreamThread(threading.Thread):
    def __init__(self, stream, *args, **kwargs) -> None: ...
    @property
    def more(self): ...
    def read(self): ...
    def stop(self) -> None: ...
    def run(self) -> None: ...

class FileVideoStream:
    def __init__(self, path, queue_size: int = ..., play_realtime: bool = ...) -> None: ...
    def start(self): ...
    def read(self): ...
    def more(self): ...
    def stop(self) -> None: ...
    def __enter__(self): ...
    def __exit__(self, type, value, traceback) -> None: ...
    def __del__(self) -> None: ...

class VideoWriter:
    output_path: Any
    fps: Any
    color: Any
    fourcc: Any
    h: Any
    w: Any
    writer: Any
    chunk_duration: Any
    chunk_count: int
    output_dir: Any
    base_filename: Any
    video_extension: Any
    def __init__(self, output_path: str = ..., fps: int = ..., color: bool = ..., codec: str = ..., chunk_duration_s: Any | None = ...) -> None: ...
    def __del__(self) -> None: ...
    def write_frame(self, frame) -> None: ...
    def close(self) -> None: ...
    def __enter__(self): ...
    def __exit__(self, type, value, traceback) -> None: ...

class EventVideoWriterState(Enum):
    IDLE: str
    RECORDING: str
    POST_ROLL: str

class _EventVideoWriterThread(threading.Thread):
    def __init__(self, output_path, fps, color, codec, queue, callback_function: Any | None = ..., callback_args=..., *args, **kwargs) -> None: ...
    def run(self) -> None: ...

class EventVideoWriter:
    def __init__(self, pre_roll: int = ..., post_roll: int = ..., fps: int = ..., color: bool = ..., codec: str = ...) -> None: ...
    @property
    def state(self): ...
    def update(self, frame) -> None: ...
    def start_event(self, output_path, callback_function: Any | None = ..., callback_args=...) -> None: ...
    def finish_event(self) -> None: ...
    def close(self) -> None: ...
    def __enter__(self): ...
    def __exit__(self, type, value, traceback) -> None: ...

class GStreamerUdpVideoWriter:
    def __init__(self, dest_ipaddr: str = ..., dest_port: int = ..., fps: int = ..., color: bool = ...) -> None: ...
    def write_frame(self, frame) -> None: ...
    def close(self) -> None: ...
    def __enter__(self): ...
    def __exit__(self, type, value, traceback) -> None: ...
    def __del__(self) -> None: ...

def translate(image, x, y): ...
def rotate(image, angle): ...
def resize(image, width: Any | None = ..., height: Any | None = ..., keep_scale: bool = ..., inter=...): ...
def list_images(base_path, contains: Any | None = ...): ...
def list_files(base_path, valid_exts=..., contains: Any | None = ...): ...
def markup_image(image, predictions, show_labels: bool = ..., show_confidences: bool = ..., colors: Any | None = ..., line_thickness: int = ..., font_size: float = ..., font_thickness: int = ...): ...
def transparent_overlay_boxes(image, predictions, alpha: float = ..., colors: Any | None = ..., show_labels: bool = ..., show_confidences: bool = ...): ...
def filter_predictions_by_label(predictions, label_list): ...
def filter_predictions_by_area(predictions, min_area_thresh): ...
def pad_to_aspect_ratio(image, a_ratio): ...
def find_usb_device(id_vendor, id_product): ...
def find_ncs2(): ...
def is_jetson(): ...
def is_jetson_nano(): ...
def is_jetson_tx2(): ...
def is_jetson_xavier_nx(): ...
def cutout_image(image, box): ...
def blur_objects(image, predictions): ...
def blend_images(foreground_image, background_image, alpha): ...
def overlay_image(foreground_image, background_image, foreground_mask): ...
def to_json_serializable(results_input): ...
